==> tutti-ui-swing-3.3-sources.jar: fr/ifremer/tutti/ui/swing/action/AbstractImportMultiPostAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: AbstractImportMultiPostAction.java 1388 2013-11-26 08:03:42Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/AbstractImportMultiPostAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.service.catches.multipost.MultiPostImportService;
import fr.ifremer.tutti.ui.swing.content.operation.FishingOperationsUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUIModel;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import org.jdesktop.beans.AbstractBean;

import java.io.File;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 2.2
 */
public abstract class AbstractImportMultiPostAction<M extends AbstractBean, UI extends TuttiUI<M, ?>, H extends AbstractTuttiUIHandler<M, UI>>
        extends AbstractTuttiAction<M, UI, H> {

    protected File file;

    protected EditFishingOperationAction editAction;

    protected MultiPostImportService multiPostImportExportService;

    public AbstractImportMultiPostAction(H handler) {
        super(handler, false);
        multiPostImportExportService = getContext().getMultiPostImportService();
    }

    public EditFishingOperationAction getEditAction() {
        FishingOperationsUI parentUI = getUI().getParentContainer(FishingOperationsUI.class);
        if (editAction == null) {
            editAction = getContext().getActionFactory().createLogicAction(parentUI.getHandler(),
                                                                           EditFishingOperationAction.class);
        }
        return editAction;
    }

    @Override
    public boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to import
            file = chooseFile(
                    getFileChooserTitle(),
                    getFileChooserButton(),
                    "^.*\\." + getFileExtension(),
                    getFileExtensionDescription()
            );
            doAction = file != null;
        }
        return doAction;
    }

    protected abstract String getFileExtension();

    protected abstract String getFileExtensionDescription();

    protected abstract String getFileChooserTitle();

    protected abstract String getFileChooserButton();

    @Override
    public void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    public void doAction() throws Exception {
        EditCatchesUI editCatchesUI = getUI().getParentContainer(EditCatchesUI.class);
        EditCatchesUIModel editCatchesUIModel = editCatchesUI.getModel();

        FishingOperation operation = editCatchesUIModel.getFishingOperation();

        importBatches(operation);

        getEditAction().loadCatchBatch(operation);
    }

    protected abstract void importBatches(FishingOperation operation);

}

==> tutti-ui-swing-3.3.1-sources.jar: fr/ifremer/tutti/ui/swing/action/AbstractImportMultiPostAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: AbstractImportMultiPostAction.java 1388 2013-11-26 08:03:42Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.3.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/AbstractImportMultiPostAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.service.catches.multipost.MultiPostImportService;
import fr.ifremer.tutti.ui.swing.content.operation.FishingOperationsUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUIModel;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import org.jdesktop.beans.AbstractBean;

import java.io.File;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 2.2
 */
public abstract class AbstractImportMultiPostAction<M extends AbstractBean, UI extends TuttiUI<M, ?>, H extends AbstractTuttiUIHandler<M, UI>>
        extends AbstractTuttiAction<M, UI, H> {

    protected File file;

    protected EditFishingOperationAction editAction;

    protected MultiPostImportService multiPostImportExportService;

    public AbstractImportMultiPostAction(H handler) {
        super(handler, false);
        multiPostImportExportService = getContext().getMultiPostImportService();
    }

    public EditFishingOperationAction getEditAction() {
        FishingOperationsUI parentUI = getUI().getParentContainer(FishingOperationsUI.class);
        if (editAction == null) {
            editAction = getContext().getActionFactory().createLogicAction(parentUI.getHandler(),
                                                                           EditFishingOperationAction.class);
        }
        return editAction;
    }

    @Override
    public boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to import
            file = chooseFile(
                    getFileChooserTitle(),
                    getFileChooserButton(),
                    "^.*\\." + getFileExtension(),
                    getFileExtensionDescription()
            );
            doAction = file != null;
        }
        return doAction;
    }

    protected abstract String getFileExtension();

    protected abstract String getFileExtensionDescription();

    protected abstract String getFileChooserTitle();

    protected abstract String getFileChooserButton();

    @Override
    public void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    public void doAction() throws Exception {
        EditCatchesUI editCatchesUI = getUI().getParentContainer(EditCatchesUI.class);
        EditCatchesUIModel editCatchesUIModel = editCatchesUI.getModel();

        FishingOperation operation = editCatchesUIModel.getFishingOperation();

        importBatches(operation);

        getEditAction().loadCatchBatch(operation);
    }

    protected abstract void importBatches(FishingOperation operation);

}
